#!/usr/bin/python
# coding: utf8
import os
import sys
import csv
from argparse import ArgumentParser
PATH_OF_THIS_SCRIPT = os.path.split(os.path.realpath(__file__))[0]
sys.path.insert(0, os.path.join(PATH_OF_THIS_SCRIPT, ".."))
from GetOrganelleLib.seq_parser import *
from GetOrganelleLib.pipe_control_func import LogInfo
from GetOrganelleLib.versions import get_versions
PATH_OF_THIS_SCRIPT = os.path.split(os.path.realpath(__file__))[0]


def get_options():
    parser = ArgumentParser(usage="summary_get_organelle_output.py list_of_folders -o tab_file")
    parser.add_argument("sample_folders", metavar="output", type=str, nargs="+",
                        help="Input a list of folders generated by get_organelle_from_reads.py."
                             "Please split the files by spaces.")
    parser.add_argument("-o", dest="output",
                        help="Output csv file.")
    # parser.add_argument("--verbose", dest="verbose", default=False, action="store_true",
    #                     help="Verbose style.")
    parser.add_argument("-v", "--version", action="version",
                        version="GetOrganelle v{version}".format(version=get_versions()))
    options = parser.parse_args()
    if not options.output or not len(options.sample_folders):
        parser.print_help()
        sys.stdout.write("Insufficient arguments!\n")
        sys.exit()
    return options


def main():
    options = get_options()
    # detect prefix
    dir_prefix_pairs = []
    for folder in options.sample_folders:
        if os.path.isdir(folder):
            prefix_list = [log_f[:-len("get_org.log.txt")]
                           for log_f in os.listdir(folder) if log_f.endswith("get_org.log.txt")]
            for this_prefix in prefix_list:
                dir_prefix_pairs.append((folder, this_prefix))
    first_sample = LogInfo(sample_out_dir=dir_prefix_pairs[0][0], prefix=dir_prefix_pairs[0][1])
    header = first_sample.header
    # if options.verbose:
    #     header.remove()
    with open(options.output, "w") as output_handler:
        res_out = csv.DictWriter(output_handler, fieldnames=header, delimiter="\t", extrasaction="ignore")
        res_out.writeheader()
        for sample_d, sample_p in dir_prefix_pairs:
            res_out.writerow(LogInfo(sample_out_dir=sample_d, prefix=sample_p).__dict__)


if __name__ == '__main__':
    main()

